@@ -1,6 +1,6 @@
 from django.db import models
 from django.utils.dates import MONTHS_3
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from polymorphic.models import PolymorphicModel
 
@@ -35,7 +35,7 @@ class Payment(PolymorphicModel):
         verbose_name_plural = _("Payments")
 
     def __str__(self):
-        return "{0} {1}".format(self.currency, self.amount)
+        return f"{self.currency} {self.amount}"
 
 
 class CreditCardPayment(Payment):
