@@ -1,11 +1,11 @@
 from django.conf import settings
-from django.conf.urls import include, url
 from django.contrib.admin import AdminSite
 from django.contrib.admin.templatetags.admin_urls import admin_urlname
 from django.contrib.auth.models import User
 from django.contrib.messages.middleware import MessageMiddleware
+from django.http.response import HttpResponse
 from django.test import RequestFactory, TestCase
-from django.urls import clear_url_caches, reverse, set_urlconf
+from django.urls import clear_url_caches, include, path, reverse, set_urlconf
 
 
 class AdminTestCase(TestCase):
@@ -20,13 +20,13 @@ class AdminTestCase(TestCase):
 
     @classmethod
     def setUpClass(cls):
-        super(AdminTestCase, cls).setUpClass()
+        super().setUpClass()
         cls.admin_user = User.objects.create_superuser(
             "admin", "admin@example.org", password="admin"
         )
 
     def setUp(self):
-        super(AdminTestCase, self).setUp()
+        super().setUp()
 
         # Have a separate site, to avoid dependency on polymorphic wrapping or standard admin configuration
         self.admin_site = AdminSite()
@@ -53,17 +53,17 @@ class AdminTestCase(TestCase):
 
         # Make sure the URLs are reachable by reverse()
         clear_url_caches()
-        set_urlconf(tuple([url("^tmp-admin/", self.admin_site.urls)]))
+        set_urlconf(tuple([path("tmp-admin/", self.admin_site.urls)]))
 
     def get_admin_instance(self, model):
         try:
             return self.admin_site._registry[model]
         except KeyError:
-            raise ValueError("Model not registered with admin: {}".format(model))
+            raise ValueError(f"Model not registered with admin: {model}")
 
     @classmethod
     def tearDownClass(cls):
-        super(AdminTestCase, cls).tearDownClass()
+        super().tearDownClass()
         clear_url_caches()
         set_urlconf(None)
 
@@ -102,9 +102,7 @@ class AdminTestCase(TestCase):
         Make a direct "add" call to the admin page, circumvening login checks.
         """
         admin_instance = self.get_admin_instance(model)
-        request = self.create_admin_request(
-            "post", self.get_add_url(model) + qs, data=formdata
-        )
+        request = self.create_admin_request("post", self.get_add_url(model) + qs, data=formdata)
         response = admin_instance.add_view(request)
         self.assertFormSuccess(request.path, response)
         return response
@@ -175,13 +173,9 @@ class AdminTestCase(TestCase):
             extra = {"data": {"post": "yes"}}
 
         admin_instance = self.get_admin_instance(model)
-        request = self.create_admin_request(
-            "post", self.get_delete_url(model, object_id), **extra
-        )
+        request = self.create_admin_request("post", self.get_delete_url(model, object_id), **extra)
         response = admin_instance.delete_view(request, str(object_id))
-        self.assertEqual(
-            response.status_code, 302, "Form errors in calling {0}".format(request.path)
-        )
+        self.assertEqual(response.status_code, 302, f"Form errors in calling {request.path}")
         return response
 
     def create_admin_request(self, method, url, data=None, **extra):
@@ -208,7 +202,7 @@ class AdminTestCase(TestCase):
         # Add properties which middleware would typically do
         request.session = {}
         request.user = self.admin_user
-        MessageMiddleware().process_request(request)
+        MessageMiddleware(lambda r: HttpResponse("OK?")).process_request(request)
         return request
 
     def assertFormSuccess(self, request_url, response):
@@ -228,11 +222,9 @@ class AdminTestCase(TestCase):
             self.assertEqual(
                 response.status_code,
                 302,
-                "Form errors in calling {0}:\n{1}".format(
-                    request_url, errors.as_text()
-                ),
+                "Form errors in calling {}:\n{}".format(request_url, errors.as_text()),
             )
         self.assertTrue(
             "/login/?next=" not in response["Location"],
-            "Received login response for {0}".format(request_url),
+            f"Received login response for {request_url}",
         )
