@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
 import uuid
 
 import django
+from django.contrib.auth.models import Group
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.db.models.query import QuerySet
@@ -9,11 +9,7 @@ from django.db.models.query import QuerySet
 from polymorphic.managers import PolymorphicManager
 from polymorphic.models import PolymorphicModel
 from polymorphic.query import PolymorphicQuerySet
-from polymorphic.showfields import (
-    ShowFieldContent,
-    ShowFieldType,
-    ShowFieldTypeAndContent,
-)
+from polymorphic.showfields import ShowFieldContent, ShowFieldType, ShowFieldTypeAndContent
 
 
 class PlainA(models.Model):
@@ -165,7 +161,7 @@ class MyManager(PolymorphicManager):
     queryset_class = MyManagerQuerySet
 
     def get_queryset(self):
-        return super(MyManager, self).get_queryset().order_by("-field1")
+        return super().get_queryset().order_by("-field1")
 
     def my_queryset_foo(self):
         return self.all().my_queryset_foo()
@@ -287,7 +283,7 @@ class InitTestModel(ShowFieldType, PolymorphicModel):
 
     def __init__(self, *args, **kwargs):
         kwargs["bar"] = self.x()
-        super(InitTestModel, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
 class InitTestModelSubclass(InitTestModel):
@@ -380,9 +376,7 @@ class ProxyModelB(ProxyModelBase):
 # with related field 'ContentType.relatednameclash_set'." (reported by Andrew Ingram)
 # fixed with related_name
 class RelatedNameClash(ShowFieldType, PolymorphicModel):
-    ctype = models.ForeignKey(
-        ContentType, on_delete=models.CASCADE, null=True, editable=False
-    )
+    ctype = models.ForeignKey(ContentType, on_delete=models.CASCADE, null=True, editable=False)
 
 
 # class with a parent_link to superclass, and a related_name back to subclass
@@ -501,3 +495,7 @@ class SubclassSelectorProxyModel(SubclassSelectorProxyBaseModel):
 
 class SubclassSelectorProxyConcreteModel(SubclassSelectorProxyModel):
     concrete_field = models.CharField(max_length=10, default="test_cf")
+
+
+class NonPolymorphicParent(PolymorphicModel, Group):
+    test = models.CharField(max_length=22, default="test_non_polymorphic_parent")
